#ifdef __cplusplus
extern "C" {
#endif


/*==================================================================================================
*                                        INCLUDE FILES
* 1) system and project includes
* 2) needed interfaces from external units
* 3) internal and external interfaces from this unit
==================================================================================================*/
#include "Clock_Ip.h"
#include "Lpspi_Ip.h"
#include "IntCtrl_Ip.h"
#include "Port_Ci_Port_Ip.h"
#include "Port_Ci_Port_Ip_Cfg.h"

#define NUMBER_OF_BYTES             (8u)
#define TIMEOUT                     ((uint32)1000000u)

/*==================================================================================================
*                                      LOCAL CONSTANTS
==================================================================================================*/
/* LPSPI 1 is used as master */
//#define MASTER_EXTERNAL_DEVICE (Lpspi_Ip_DeviceAttributes_SpiExternalDevice_Master_BOARD_InitPeripherals)
#define SLAVE_EXTERNAL_DEVICE (Lpspi_Ip_DeviceAttributes_SpiExternalDevice_Slave_BOARD_InitPeripherals)


#define SPI_START_SEC_VAR_CLEARED_8_NO_CACHEABLE
#include "Spi_MemMap.h"
uint8 TxMasterBuffer[NUMBER_OF_BYTES];
uint8 RxSlaveBuffer[NUMBER_OF_BYTES];
#define SPI_STOP_SEC_VAR_CLEARED_8_NO_CACHEABLE
#include "Spi_MemMap.h"

bool boTest = false;

Lpspi_Ip_CallbackType EndCallback(uint8 Instance, Lpspi_Ip_EventType event)
{
	boTest = true;
}

int main(void)
{
    Lpspi_Ip_HwStatusType Status;



    /* Initalized clock */
    Clock_Ip_Init(&Mcu_aClockConfigPB[0]);

    /* Init Port */
    Port_Ci_Port_Ip_Init(NUM_OF_CONFIGURED_PINS0, g_pin_mux_InitConfigArr0);

    /* Initialize interrupt */
    IntCtrl_Ip_Init(&IntCtrlConfig_0);
    IntCtrl_Ip_ConfigIrqRouting(&intRouteConfig);

    /* Initalized spi using instance lpspi as a spi slave */
    Lpspi_Ip_Init(&Lpspi_Ip_PhyUnitConfig_SpiPhyUnit_0_BOARD_InitPeripherals);

    /* Update Transfer Mode */
    Lpspi_Ip_UpdateTransferMode(SLAVE_EXTERNAL_DEVICE.Instance, LPSPI_IP_INTERRUPT);

//    Lpspi_Ip_IrqHandler(SLAVE_EXTERNAL_DEVICE.Instance);

    /* Slave set up and waiting active signal of Cs from master to process data reception */
    Lpspi_Ip_AsyncTransmitHalfDuplex(&SLAVE_EXTERNAL_DEVICE, RxSlaveBuffer, (uint16)NUMBER_OF_BYTES, LPSPI_IP_HALF_DUPLEX_RECEIVE, EndCallback);

    do
    {
        Status = Lpspi_Ip_GetStatus(Lpspi_Ip_DeviceAttributes_SpiExternalDevice_Slave_BOARD_InitPeripherals.Instance);

        uint32_t sr = IP_LPSPI1->SR;
    }
    while ( Status != LPSPI_IP_IDLE );


    return 0;
}



#ifdef __cplusplus
}
#endif

/** @} */
